<?php

namespace Drupal\core_event_dispatcher\Event\Core;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Database\Query\AlterableInterface;
use Drupal\core_event_dispatcher\CoreHookEvents;
use Drupal\hook_event_dispatcher\Attribute\HookEvent;
use Drupal\hook_event_dispatcher\Event\EventInterface;

/**
 * Defines class QueryAlterEvent.
 */
#[HookEvent(id: 'query_alter', alter: 'query')]
class QueryAlterEvent extends Event implements EventInterface {

  /**
   * ViewsQueryAlterEvent constructor.
   *
   * @param \Drupal\Core\Database\Query\AlterableInterface $query
   *   The query.
   */
  public function __construct(private readonly AlterableInterface $query) {
  }

  /**
   * Get the query.
   *
   * @return \Drupal\Core\Database\Query\AlterableInterface
   *   The query.
   */
  public function getQuery(): AlterableInterface {
    return $this->query;
  }

  /**
   * {@inheritdoc}
   */
  public function getDispatcherType(): string {
    return CoreHookEvents::QUERY_ALTER;
  }

}
