<?php

namespace Drupal\Tests\core_event_dispatcher\Kernel\Core;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\Tests\user\Traits\UserCreationTrait;
use Drupal\core_event_dispatcher\CoreHookEvents;
use Drupal\core_event_dispatcher\Event\Core\QueryAlterEvent;

/**
 * Defines class QueryAlterEventTest.
 *
 * @covers \Drupal\core_event_dispatcher\Event\Core\QueryAlterEvent
 *
 * @group hook_event_dispatcher
 * @group core_event_dispatcher
 */
class QueryAlterEventTest extends KernelTestBase {

  use ListenerTrait;
  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'hook_event_dispatcher',
    'core_event_dispatcher',
    'system',
    'user',
  ];

  /**
   * Test the QueryAlterEvent.
   *
   * @throws \Exception
   */
  public function testQueryAlterEvent(): void {
    $this->listen(CoreHookEvents::QUERY_ALTER, 'onQueryAlter');

    $this->installEntitySchema('user');
    // Create 2 users.
    $this->createUser([], 'user1', FALSE, ['uid' => 1]);
    $this->createUser([], 'user2', FALSE, ['uid' => 2]);

    $userCount = $this->container->get('entity_type.manager')->getStorage('user')->getQuery()
      ->accessCheck(FALSE)
      ->count()
      ->execute();

    $this->assertEquals(1, $userCount);
  }

  /**
   * Callback for QueryAlterEvent.
   *
   * @param \Drupal\core_event_dispatcher\Event\Core\QueryAlterEvent $event
   *   The event.
   */
  public function onQueryAlter(QueryAlterEvent $event): void {
    /** @var \Drupal\Core\Entity\Query\QueryInterface $query */
    $query = $event->getQuery();
    $this->assertInstanceOf('\Drupal\Core\Database\Query\AlterableInterface', $query);
    $query->condition('uid', 1);
  }

}
